@@ -17,13 +17,12 @@ function(x,writeToFile,removeTermsOrHashtags, ...)
 
   dataCombinedUNIQUE <- x # match the variable names (this must be used to avoid warnings in package compilation)
 
-  # Warn the user if they are trying to create a bimodal network
-  # using TEMPORAL data (i.e. it might work, but could be compatibility issues)
-
-  if (inherits(dataCombinedUNIQUE,"temporal")) {
-    cat("\nERROR. Attempting to use dynamic data to create bimodal network. Please use the 'dynamic=FALSE' argument when collecting data.\n")
-    return()
-  }
+  # if `dataCombinedUNIQUE` is a list of dataframes, then need to convert these into one dataframe
+  suppressWarnings(
+    if (class(dataCombinedUNIQUE)=="list") {
+    dataCombinedUNIQUE <- do.call("rbind", dataCombinedUNIQUE)
+    }
+  )
 
   #EnsurePackage("igraph")
 
@@ -33,12 +32,18 @@ function(x,writeToFile,removeTermsOrHashtags, ...)
   usersVec <- rep(c("User"),length(unique(dataCombinedUNIQUE$from)))
   postsVec <- rep(c("Post"),length(unique(dataCombinedUNIQUE$to)))
   usersAndPostsVec <- c(usersVec,postsVec)
-  actors <- data.frame(name=unique(factor(c(as.character(unique(dataCombinedUNIQUE$from)),as.character(unique(dataCombinedUNIQUE$to))))),type=usersAndPostsVec)
+  actors <- data.frame(name=unique(factor(c(as.character(unique(dataCombinedUNIQUE$from)),
+  as.character(unique(dataCombinedUNIQUE$to))))),type=usersAndPostsVec)
 
   # make a dataframe of the relations between actors
   # we need a dataframe here because igraph needs it AFAIK
 
-  relations <- data.frame(from=dataCombinedUNIQUE$from,to=dataCombinedUNIQUE$to,relationship=dataCombinedUNIQUE$relationship,weight=dataCombinedUNIQUE$edgeWeight)
+  relations <- data.frame(
+    from=dataCombinedUNIQUE$from,
+    to=dataCombinedUNIQUE$to,
+    edgeType=dataCombinedUNIQUE$edgeType,
+    timestamp=dataCombinedUNIQUE$commentTimestamp
+    )
 
   # construct a graph
   g <- graph.data.frame(relations, directed=TRUE, vertices=actors)
@@ -46,6 +51,13 @@ function(x,writeToFile,removeTermsOrHashtags, ...)
   # Make the node labels play nice with Gephi
   V(g)$label <- V(g)$name
 
+  # for some reason the dummy row is still generating the "foo" node!
+  # a quick way to fix this for now:
+  toDel <- which(V(g)$name=="foo" | V(g)$name=="buzz" | V(g)$name=="fizz" | V(g)$name=="bar")
+  if (length(toDel)>0) {
+    g <- delete.vertices(g, toDel)
+  }
+
   if (writeToFile=="TRUE" | writeToFile=="true" | writeToFile=="T" | writeToFile==TRUE) {
     # Output the final network to a graphml file, to import directly into Gephi
     currTime <- format(Sys.time(), "%b_%d_%X_%Y_%Z")
