@@ -30,6 +30,13 @@ function(x,writeToFile,termFreq,hashtagFreq,removeTermsOrHashtags,stopwordsEngli
 
   df <- x # match the variable names (this must be used to avoid warnings in package compilation)
 
+  # if `df` is a list of dataframes, then need to convert these into one dataframe
+  suppressWarnings(
+    if (class(df)=="list") {
+    df <- do.call("rbind", df)
+    }
+  )
+  
   EnsurePackage("igraph")
 
       # Now create the dfSemanticNetwork3,
@@ -218,10 +225,12 @@ function(x,writeToFile,termFreq,hashtagFreq,removeTermsOrHashtags,stopwordsEngli
       ##### STEP FOUR #####
 
       # convert into a graph
-      g <- graph.data.frame(relations, directed=FALSE, vertices=actorsFixed)
+      suppressWarnings(
+        g <- graph.data.frame(relations, directed=FALSE, vertices=actorsFixed)
+      )
       # we need to simplify the graph because multiple use of same term
       # in one tweet will cause self-loops, etc
-      g <- simplify(g)
+      # g <- simplify(g)
 
       # Make the node labels play nice with Gephi
       V(g)$label <- V(g)$name
